.. ALMAQSO documentation master file, created by
   sphinx-quickstart on Mon Nov 25 18:11:17 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ALMAQSO documentation
=====================



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
